package de.quipus.demo.jco;

/**
 * @author Ingo Sauerzapf
 *
 * Dies ist eine Demo mit der gezeigt werden soll
 * wie man mit hilfe des Java Connectors von SAP
 * einen Funktionsbaustein/Bapi aufrufen kann um
 * Daten aus dem SAP System zu lesen. Die Demo
 * bedient sich hier Klassen die mit dem SAP Java
 * Connectivity Builder vorher aus dem SAP System
 * erzeugt wurden. 
 */

import com.sap.aii.proxy.framework.core.ApplicationFaultException;
import com.sap.aii.proxy.framework.core.SystemFaultException;
import com.sap.mw.jco.JCO;
import de.quipus.sapproxy.Bapi_Employee_Getdata_Input;
import de.quipus.sapproxy.Bapi_Employee_Getdata_Output;
import de.quipus.sapproxy.Bapip0002BType;
import de.quipus.sapproxy.Bapip0002BTypeList;
import de.quipus.sapproxy.BapireturnType;
import de.quipus.sapproxy.Employee_PortType;



public class EmployeeWithProxy {

	public static void main(String[] args) {
		
        System.out.println("Dies ist die Demo mit dem Proxy");


        // Erzeuge eine Verbindung zum SAP System
		JCO.Client client =  JCO.createClient("000",  	      // Mandant
											  "username",     // Username
											  "password", // Passwort
											  "DE",           // Sprace
											  "saphostname", // SAP Host
											  "00");          // SAP Systemnummer
		
		// ffnen der Verbindung
		client.connect();
		
		// Erzeugen des Imput Objects fr den SAP Funktionsbaustein/BAPI
		Bapi_Employee_Getdata_Input input = 
		   new Bapi_Employee_Getdata_Input();
	
		// hier setzten wir nun den Parameter der den Funktiosbaustein im
		// SAP System mitteilt, das wir nur nach Mitarbeitern suchen die
		// Nachnamen haben die mit Z anfangen
		input.setLastname_M("Z*");
				   
		
		// Erzeugen einer instanz des Proxies
		Employee_PortType proxy =
		    new Employee_PortType();

		    
		// Nun bergeben wir die erzeugte Verbindung an den Proxy weiter
		proxy.messageSpecifier.setJcoClient(client);
		

		
		try {
		
		// Fhre den proxy aus und Suche alle Mitarbeiter die mit Z beginnen
		   Bapi_Employee_Getdata_Output output =
		          proxy.bapi_Employee_Getdata(input);	   
		   
		// Jetzt schauen wir nach, ob es einen Fehler im SAP System gegeben hat
		// in BAPIs gibt es hierfr eine Rckgabestruktur die man ala SAP
		// auswerten kann. Sie enthlt einen Rckgabetyp der entweder 'S' fr success
		// 'W' fr warning 'E' fr error oder auch leer sein kann.  
		   BapireturnType ret = output.getReturn();
		   
		   if ( ret.getType() == "E" ){
		   	  System.out.println("Es ist ein Fehler im SAP System Aufgetreten");
		   	  System.out.println("der Fehler war " + ret.getMessage());
		   } else {
		   	
		   	// Da wir jetzt sicher sein knnen, das wir zumindes keinen
		   	// Fehler im SAP System gehabt haben werden wir und die
		   	// Liste von Personen zuckgeben lassen die das SAP System
		   	// gefunden hat		   	
		   	Bapip0002BTypeList personalList = output.getPersonal_Data();
		   			   	
		   	if ( personalList.size() > 0){
		   	  System.out.println("Personalnr.:   Name:     Geburtstag:");
		   	  
		   	  for ( int i = 0; i < personalList.size(); i++){

		   			Bapip0002BType personaldata = personalList.getBapip0002BType(i);

		   			// Nun geben wir lediglich die Informationen aus die uns hier
		   			// interresieren
		   			System.out.print(personaldata.getPerno());
		   			System.out.print("       " +personaldata.getLast_Name());
		   			System.out.print( " " + personaldata.getFirstname());
		   			System.out.println("   " + personaldata.getBirthdate());

		   			// Es knnen beliebige andere Informationen aus dem System
		   			// gelesen wurden
		   	   }		   	  
		   	  		   	  
		   	} else {
		   	  System.out.println("Es wurden keine Personen deren Nachname mit Z anfngt gefunden.");		   	
		   	}
		   	
		   }
		      
		    // hier schliessen wir die Verbindung wieder  
		    client.disconnect();
		   
		} catch (ApplicationFaultException afx){
		   afx.printStackTrace();			
		} catch (SystemFaultException sfx){
		   sfx.printStackTrace();	
		}   
		   		
	}
}
