package de.quipus.demo.jco;

/**
 * @author Ingo Sauerzapf
 *
 * Dies ist eine Demo mit der gezeigt werden soll
 * wie man mit hilfe des Java Connectors von SAP
 * einen Funktionsbaustein/Bapi aufrufen kann um
 * Daten aus dem SAP System zu lesen. Die demo
 * verwendet keine weiteren Hilfsmittel neben dem
 * SAP Java Connector.
 */


import com.sap.mw.jco.IFunctionTemplate;
import com.sap.mw.jco.JCO;

public class EmployeeWithoutProxy {

	public static void main(String[] args) {

	  try {

	  	System.out.println("Dies ist die Demo ohne den Proxy");
		
		// Erzeuge eine Verbindung zum SAP System
		JCO.Client client =  JCO.createClient("000",  	      // Mandant
											  "username",         // Username
											  "passwort",     // Passwort
											  "DE",           // Sprace
											  "saphostname", // SAP Host
											  "00");          // SAP Systemnummer
	 										  
		client.connect();
		
		// hier erzeugen wir ein repository object. dieses wir
		// uns nun aus dem SAP System die Schnittstelle des
		// Funktionsbausteins holen den wir danach aufrufen wollen.
		JCO.Repository repository =
		     new JCO.Repository("MYREPOSITORY", client);
		
		// hier sagen wir nun dem repository das es im SAP System
		// nachschauen soll wie die Schnittstelle des Funktionsbausteins
		// aussieht. Dies erzeugt mehrer Aufrufe von Funktionsbausteinen
		// die die Schnittstelle des Funktionsbausteins dem repository
		// zurckgeben.     
		IFunctionTemplate ft = repository.getFunctionTemplate("BAPI_EMPLOYEE_GETDATA");
		
		
		
		// gibt den Funktionsbaustein zurck
		JCO.Function function = ft.getFunction();
		
		// hier setzten wir nun den Parameter der den Funktiosbaustein im
		// SAP System mitteilt, das wir nur nach Mitarbeitern suchen die
		// Nachnamen haben die mit Z anfangen
		function.getImportParameterList().setValue( "Z*", "LASTNAME_M");
		 
		// hier schieben wir nun den functionsbaustein in die Verbindung
		// zum SAP system hinein und frhren den Funktionsbaustein aus		
		client.execute(function);
		
		JCO.Table personalList =
		    function.getTableParameterList().getTable("PERSONAL_DATA");
		    
		if (personalList.getNumRows() > 0){
		
		  System.out.println("Personalnr.:   Name:      Geburtstag:");		
		  for ( int i = 0; i < personalList.getNumRows(); i++, personalList.nextRow()){
		
			// Nun geben wir lediglich die Informationen aus die uns hier
			// interresieren. Hierbei ist zu Beachten, das die einzelnen
			System.out.print(personalList.getString("PERNO"));
			System.out.print("       " + personalList.getString("LAST_NAME"));
			System.out.print( " " + personalList.getString("FIRSTNAME"));
			
			// Wenn wir hier das Datum ausgeben wird es im Format von Java
			// zurckgegeben. 
			System.out.println("   " + personalList.getDate("BIRTHDATE"));
			
		  } 
	    } else {
		   System.out.println("Es wurden keine Personen deren Nachname mit Z anfngt gefunden.");
		}
											  
											  		
		client.disconnect();
	
	  } catch ( Exception ex) {
	    	System.out.println("Es ist ein Fehler aufgetreten");
	    	ex.printStackTrace();
	  } 
		
	}
}
